.. _source:


.. raw:: html

     <br><br>

.. title:: Source


.. raw:: html

    <center><b>SOURCE</b></center><br>


**OTPCR**

.. raw:: html

     <br>

.. autosummary::
    :toctree: 
    :template: base.rst


    otpcr.client
    otpcr.disk
    otpcr.event
    otpcr.find
    otpcr.fleet
    otpcr.handler
    otpcr.json
    otpcr.object
    otpcr.store
    otpcr.thread


.. raw:: html

     <br>


**MODULES**


.. raw:: html

     <br>


.. autosummary::
    :toctree: 
    :template: base.rst

    otpcr.modules.err
    otpcr.modules.flt
    otpcr.modules.fnd
    otpcr.modules.irc
    otpcr.modules.llm
    otpcr.modules.log
    otpcr.modules.man
    otpcr.modules.mbx
    otpcr.modules.mdl
    otpcr.modules.mod
    otpcr.modules.req
    otpcr.modules.rss
    otpcr.modules.rst
    otpcr.modules.slg
    otpcr.modules.tbl
    otpcr.modules.tdo
    otpcr.modules.thr
    otpcr.modules.tmr
    otpcr.modules.udp
    otpcr.modules.upt
    otpcr.modules.ver
    otpcr.modules.web
    otpcr.modules.wsd
